@@ -12,4 +12,6 @@ facebook <- oauth_endpoint(
 myapp <- oauth_app("facebook", "353609681364760")
 
 # 3. Get OAuth credentials
-cred <- parse_query(oauth2.0(facebook, myapp))
+facebook_token <- oauth2.0_token(facebook, myapp,
+  type = "application/x-www-form-urlencoded")
+facebook_sig <- sign_oauth2.0(facebook_token$access_token)
