@@ -2,7 +2,7 @@ library(httr)
 
 # 1. Find OAuth settings for google:
 #    https://developers.google.com/accounts/docs/OAuth2InstalledApp
-google <- oauth_endpoint(NULL, "auth", "token", 
+google <- oauth_endpoint(NULL, "auth", "token",
   base_url = "https://accounts.google.com/o/oauth2")
 
 # 2. Register an application at https://code.google.com/apis/console#access
@@ -11,5 +11,5 @@ google <- oauth_endpoint(NULL, "auth", "token",
 myapp <- oauth_app("google", "16795585089.apps.googleusercontent.com")
 
 # 3. Get OAuth credentials
-cred <- oauth2.0(google, myapp, 
+cred <- oauth2.0_token(google, myapp,
   scope = "https://www.googleapis.com/auth/userinfo.profile")
