@@ -3,7 +3,7 @@ context("Send data")
 round_trip <- function(method, body = NULL, ...) {
   url <- str_c("http://httpbin.org/", tolower(method))
   request <- match.fun(toupper(method))
-  parsed_content(request(url, body = body, ...))
+  content(request(url, body = body, ...))
 }
 methods <- c("POST", "PUT")
 
@@ -34,9 +34,9 @@ test_that("named list matches form results", {
 
 test_that("file and form vals mixed give form and data elements", {
   for(method in methods) {
-    out <- round_trip(method, list(y = citation, a = 1))  
+    out <- round_trip(method, list(y = citation, a = 1))
     expect_equal(out$form$a, "1", info = method)
-    expect_equal(str_split(out$file$y, "\n")[[1]], citation_val, 
+    expect_equal(str_split(out$file$y, "\n")[[1]], citation_val,
       info = method)
   }
-})
\ No newline at end of file
+})
